pub fn extract_bundled_thread(
event: &Raw<AnySyncTimelineEvent>,
) -> Option<BundledThread>Expand description
Try to extract a bundled thread of a timeline event, if available.
pub fn extract_bundled_thread(
event: &Raw<AnySyncTimelineEvent>,
) -> Option<BundledThread>Try to extract a bundled thread of a timeline event, if available.