extract_is_thread_root

Function extract_is_thread_root 

pub fn extract_is_thread_root(event: &Raw<AnySyncTimelineEvent>) -> bool
Try to extract whether the event is a thread root, i.e. if it has an "unsigned"."m.relations"."m.thread" field, i.e. if the event has a thread summary/bundled thread.

This is the question-variant of extract_bundled_thread. This latter will deserialise the whole BundledThread whilst this function will just look at the path.